@@ -10,7 +10,9 @@ import functools
 
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
-from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMinimum
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMin
+from PyFin.Analysis.TechnicalAnalysis import SecurityMaximumValueHolder
+from PyFin.Analysis.TechnicalAnalysis import SecurityMinimumValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingQuantile
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAllTrue
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAnyTrue
@@ -36,6 +38,7 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityAcosValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAcoshValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAsinValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAsinhValueHolder
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingResidue
 from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityIIFValueHolder
@@ -84,6 +87,10 @@ def RSI(window, dependency='x'):
     return SecurityMovingRSI(window, dependency)
 
 
+def RES(window, dependency=('y', 'x')):
+    return SecurityMovingResidue(window, dependency)
+
+
 def MA(window, dependency='x'):
     return SecurityMovingAverage(window, dependency)
 
@@ -93,7 +100,15 @@ def MMAX(window, dependency='x'):
 
 
 def MMIN(window, dependency='x'):
-    return SecurityMovingMinimum(window, dependency)
+    return SecurityMovingMin(window, dependency)
+
+
+def MAXIMUM(dependency=('x', 'y')):
+    return SecurityMaximumValueHolder(dependency)
+
+
+def MINIMUM(dependency=('x', 'y')):
+    return SecurityMinimumValueHolder(dependency)
 
 
 def MQUANTILE(window, dependency='x'):
