@@ -25,6 +25,8 @@ from PyFin.api.Analysis import RSI
 from PyFin.api.Analysis import MA
 from PyFin.api.Analysis import MMAX
 from PyFin.api.Analysis import MMIN
+from PyFin.api.Analysis import MAXIMUM
+from PyFin.api.Analysis import MINIMUM
 from PyFin.api.Analysis import MQUANTILE
 from PyFin.api.Analysis import MALLTRUE
 from PyFin.api.Analysis import MANYTRUE
@@ -53,6 +55,7 @@ from PyFin.api.Analysis import ASIN
 from PyFin.api.Analysis import ASINH
 from PyFin.api.Analysis import SHIFT
 from PyFin.api.Analysis import IIF
+from PyFin.api.Analysis import RES
 
 from PyFin.api.Analysis import CSRank
 from PyFin.api.Analysis import CSMean
@@ -60,6 +63,8 @@ from PyFin.api.Analysis import CSMeanAdjusted
 from PyFin.api.Analysis import CSQuantile
 from PyFin.api.Analysis import CSZScore
 
+from PyFin.Utilities.Asserts import pyFinAssert
+
 
 __all__ = ["datesList",
            "bizDatesList",
@@ -80,6 +85,8 @@ __all__ = ["datesList",
            "MA",
            "MMAX",
            "MMIN",
+           "MAXIMUM",
+           "MINIMUM",
            "MQUANTILE",
            "MALLTRUE",
            "MANYTRUE",
@@ -106,10 +113,12 @@ __all__ = ["datesList",
            "ACOSH",
            "ASIN",
            "ASINH",
+           "RES",
            "SHIFT",
            "IIF",
            "CSRank",
            "CSMean",
            "CSMeanAdjusted",
            "CSQuantile",
-           "CSZScore"]
+           "CSZScore",
+           "pyFinAssert"]
