@@ -18,7 +18,7 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingVariance
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingStandardDeviation
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
-from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMinimum
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMin
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingQuantile
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAllTrue
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAnyTrue
@@ -29,6 +29,7 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityMovingPositiveDifferenceAve
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingNegativeDifferenceAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingRSI
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingLogReturn
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingResidue
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingHistoricalWindow
 
 
@@ -268,7 +269,7 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
 
     def testSecurityMovingMinimum(self):
         window = 10
-        ma1 = SecurityMovingMinimum(window, ['close'])
+        ma1 = SecurityMovingMin(window, ['close'])
 
         for i in range(len(self.aapl['close'])):
             data = dict(aapl=dict(close=self.aapl['close'][i],
@@ -290,13 +291,13 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                                                                  'calculated: {2:.12f}'.format(i, expected, calculated))
 
         with self.assertRaises(ValueError):
-            _ = SecurityMovingMinimum(window, ['close', 'open'])
+            _ = SecurityMovingMin(window, ['close', 'open'])
 
     def testSecurityMovingMinimumDeepcopy(self):
-        self.template_test_deepcopy(SecurityMovingMinimum, window=10, dependency=['x'])
+        self.template_test_deepcopy(SecurityMovingMin, window=10, dependency=['x'])
 
     def testSecurityMovingMinimumPickle(self):
-        self.template_test_pickle(SecurityMovingMinimum, window=10, dependency=['x'])
+        self.template_test_pickle(SecurityMovingMin, window=10, dependency=['x'])
 
     def testSecurityMovingQuantile(self):
         window = 10
@@ -736,3 +737,76 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
             if i >= 1:
                 self.assertAlmostEqual(max(container), compounded1.value['aapl'], 12)
                 self.assertAlmostEqual(np.mean((container)), compounded2.value['aapl'], 12)
+
+    def testSecurityMovingResidue(self):
+        window =100
+        mr = SecurityMovingResidue(window, ('y', 'x'))
+        for i in range(len(self.aapl['close'])):
+            data = {'aapl': {'y': self.aapl['close'][i], 'x': self.aapl['open'][i]},
+                    'ibm': {'y': self.ibm['close'][i], 'x': self.ibm['open'][i]}}
+            mr.push(data)
+
+            if i >= window - 1:
+                for name in mr.value.index():
+                    series_x = getattr(self, name)['open'][i - window + 1:i + 1]
+                    series_y = getattr(self, name)['close'][i - window + 1:i + 1]
+                    expected_res = series_y[-1] - np.dot(series_x, series_y) / np.dot(series_x, series_x) * series_x[-1]
+                    self.assertAlmostEqual(mr.value[name], expected_res, msg= \
+                                           "at index {0} and symbol {1}\n"
+                                           "expected:   {2}\n"
+                                           "calculated: {3}".format(i, name, expected_res, mr.value[name]))
+
+    def testSecurityMovingResidueDeepcopy(self):
+        ma = SecurityMovingResidue(10, ['y', 'x'])
+
+        data = dict(aapl=dict(x=1., y=2),
+                    ibm=dict(x=2., y=3))
+        data2 = dict(aapl=dict(x=2., y=3),
+                     ibm=dict(x=3., y=4))
+
+        ma.push(data)
+        ma.push(data2)
+
+        copied = copy.deepcopy(ma)
+
+        for i, v in enumerate(np.random.rand(20)):
+            data['aapl']['x'] = v
+            data['aapl']['y'] = v + 1
+            data['ibm']['x'] = v + 1.
+            data['ibm']['y'] = v + 2.
+            ma.push(data)
+            copied.push(data)
+            if i >= 10:
+                for name in ma.value.index():
+                    self.assertAlmostEqual(ma.value[name], copied.value[name])
+
+    def testSecurityMovingResiduePickle(self):
+        ma = SecurityMovingResidue(10, ['y', 'x'])
+
+        data = dict(aapl=dict(x=1., y=2),
+                    ibm=dict(x=2., y=3))
+        data2 = dict(aapl=dict(x=2., y=3),
+                     ibm=dict(x=3., y=4))
+
+        ma.push(data)
+        ma.push(data2)
+
+        with tempfile.NamedTemporaryFile('w+b', delete=False) as f:
+            pickle.dump(ma, f)
+
+        with open(f.name, 'rb') as f2:
+            pickled = pickle.load(f2)
+        os.unlink(f.name)
+
+        for i, v in enumerate(np.random.rand(20)):
+            data['aapl']['x'] = v
+            data['aapl']['y'] = v + 1
+            data['ibm']['x'] = v + 1.
+            data['ibm']['y'] = v + 2.
+            ma.push(data)
+            pickled.push(data)
+
+            if i >= 10:
+                for name in ma.value.index():
+                    self.assertAlmostEqual(ma.value[name], pickled.value[name])
+
