@@ -14,6 +14,7 @@ from PyFin.Analysis.CrossSectionValueHolders import CSRankedSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageAdjustedSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSQuantileSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSZScoreSecurityValueHolder
 
 
 class TestCrossSectionValueHolder(unittest.TestCase):
@@ -38,7 +39,7 @@ class TestCrossSectionValueHolder(unittest.TestCase):
             benchmark.push(data)
             rankHolder.push(data)
             benchmarkValues = benchmark.value
-            np.testing.assert_array_almost_equal(benchmarkValues.rank(), rankHolder.value)
+            np.testing.assert_array_almost_equal(benchmarkValues.rank().values, rankHolder.value.values)
 
     def testCSRankedSecurityValueHolder(self):
         benchmark = SecurityLatestValueHolder(dependency='close')
@@ -52,7 +53,7 @@ class TestCrossSectionValueHolder(unittest.TestCase):
             benchmark.push(data)
             rankHolder.push(data)
             benchmarkValues = benchmark.value
-            np.testing.assert_array_almost_equal(benchmarkValues.rank(), rankHolder.value)
+            np.testing.assert_array_almost_equal(benchmarkValues.rank().values, rankHolder.value.values)
 
     def testCSAverageSecurityValueHolder(self):
         benchmark = SecurityLatestValueHolder(dependency='close')
@@ -66,9 +67,9 @@ class TestCrossSectionValueHolder(unittest.TestCase):
             benchmark.push(data)
             meanHolder.push(data)
             benchmarkValues = benchmark.value
-            np.testing.assert_array_almost_equal(benchmarkValues.mean(), meanHolder.value)
+            np.testing.assert_array_almost_equal(benchmarkValues.mean(), meanHolder.value.values)
 
-    def testCSAverageSecurityValueHolder(self):
+    def testCSAverageAdjustedSecurityValueHolder(self):
         benchmark = SecurityLatestValueHolder(dependency='close')
         meanAdjustedHolder = CSAverageAdjustedSecurityValueHolder(benchmark)
 
@@ -80,7 +81,7 @@ class TestCrossSectionValueHolder(unittest.TestCase):
             benchmark.push(data)
             meanAdjustedHolder.push(data)
             benchmarkValues = benchmark.value
-            np.testing.assert_array_almost_equal(benchmarkValues - benchmarkValues.mean(), meanAdjustedHolder.value)
+            np.testing.assert_array_almost_equal(benchmarkValues.values - benchmarkValues.mean(), meanAdjustedHolder.value.values)
 
     def testCSQuantileSecurityValueHolder(self):
         keys = list(range(1, 11))
@@ -94,10 +95,31 @@ class TestCrossSectionValueHolder(unittest.TestCase):
 
         quantile_value = CSQuantileSecurityValueHolder('close')
         quantile_value.push(data)
-        calculated = quantile_value.value.sort_index()
+
+        calculated = quantile_value.value
 
         data = np.linspace(1., 0., 10)
 
         expected = pd.Series(data=data, index=[x for x in range(1, 11)])
 
-        np.testing.assert_array_almost_equal(expected.values, calculated.values)
\ No newline at end of file
+        np.testing.assert_array_almost_equal(expected.values, calculated.values)
+
+    def testCSZscoreSecurityValueHolder(self):
+        keys = list(range(1, 11))
+        values = list(range(10, 0, -1))
+
+        data = {}
+
+        for i, k in enumerate(keys):
+            data[k] = {}
+            data[k]['close'] = values[i]
+
+        quantile_value = CSZScoreSecurityValueHolder('close')
+        quantile_value.push(data)
+
+        calculated = quantile_value.value
+
+        data = np.linspace(10., 1., 10)
+        expected = (data - data.mean()) / data.std()
+
+        np.testing.assert_array_almost_equal(expected, calculated.values)
\ No newline at end of file
