@@ -18,7 +18,7 @@ from PyFin.Math.Accumulators import Latest
 from PyFin.Math.Accumulators import Shift
 from PyFin.Math.Accumulators import Exp
 from PyFin.Math.Accumulators import MovingMax
-from PyFin.Math.Accumulators import MovingMinimum
+from PyFin.Math.Accumulators import MovingMin
 from PyFin.Math.Accumulators import MovingQuantile
 from PyFin.Math.Accumulators import MovingAllTrue
 from PyFin.Math.Accumulators import MovingAnyTrue
@@ -52,6 +52,7 @@ from PyFin.Math.Accumulators import MovingBias
 from PyFin.Math.Accumulators import MovingAroon
 from PyFin.Math.Accumulators import MovingLevel
 from PyFin.Math.Accumulators import MovingAutoCorrelation
+from PyFin.Math.Accumulators import MovingResidue
 
 
 class TestStatefulAccumulators(unittest.TestCase):
@@ -592,7 +593,7 @@ class TestStatefulAccumulators(unittest.TestCase):
     def testMovingMinimum(self):
         window = 120
 
-        mv = MovingMinimum(window, dependency='z')
+        mv = MovingMin(window, dependency='z')
         total = np.random.randn(2500)
         con = deque(maxlen=window)
         for i, value in enumerate(total):
@@ -608,7 +609,7 @@ class TestStatefulAccumulators(unittest.TestCase):
                                                              "Min calculated: {2:f}".format(i, expected, calculated))
 
     def testMovingMinimumDeepcopy(self):
-        test = MovingMinimum(3, 'close')
+        test = MovingMin(3, 'close')
 
         test.push(dict(close=3.0))
         test.push(dict(close=4.0))
@@ -618,7 +619,7 @@ class TestStatefulAccumulators(unittest.TestCase):
         self.assertAlmostEqual(copied.value, test.value)
 
     def testMovingMinimumPickle(self):
-        test = MovingMinimum(3, 'close')
+        test = MovingMin(3, 'close')
 
         test.push(dict(close=3.0))
         test.push(dict(close=4.0))
@@ -2227,6 +2228,70 @@ class TestStatefulAccumulators(unittest.TestCase):
         self.assertAlmostEqual(mv.value, pickled.value)
         os.unlink(f.name)
 
+    def testMovingResidue(self):
+        window = 100
+        x_data = np.random.randn(10000)
+
+        mr = MovingResidue(window)
+
+        for i, value in enumerate(zip(x_data, self.sample)):
+            x = value[0]
+            y = value[1]
+
+            mr.push(dict(x=x, y=y))
+
+            if i >= window - 1:
+                series_x = x_data[i-window+1:i+1]
+                series_y = self.sample[i-window+1:i+1]
+
+                calculated_res = mr.result()
+                expected_res = y - np.dot(series_x, series_y) / np.dot(series_x, series_x) * x
+                self.assertAlmostEqual(expected_res, calculated_res, 8, "at index of {0:d}\n"
+                                                                        "expected res:  {1:f}\n"
+                                                                        "calculated res:{2:f}".format(i,
+                                                                                                      expected_res,
+                                                                                                      calculated_res))
+
+    def testMovingResidueDeepcopy(self):
+        window = 10
+        mr = MovingResidue(window)
+
+        mr.push(dict(x=-1., y=0))
+        mr.push(dict(x=-2., y=-1))
+        mr.push(dict(x=-3., y=-2))
+        mr.push(dict(x=-4., y=-3))
+
+        copied = copy.deepcopy(mr)
+
+        datas = np.random.randn(40)
+        for i in datas:
+            mr.push(dict(x=i, y=i+1.))
+            copied.push(dict(x=i, y=i+1))
+
+        self.assertAlmostEqual(copied.value, mr.value)
+
+    def testMovingResiduePickle(self):
+        window = 10
+        mr = MovingResidue(window)
+
+        mr.push(dict(x=-1., y=0))
+        mr.push(dict(x=-2., y=-1))
+        mr.push(dict(x=-3., y=-2))
+
+        with tempfile.NamedTemporaryFile('w+b', delete=False) as f:
+            pickle.dump(mr, f)
+
+        with open(f.name, 'rb') as f2:
+            pickled = pickle.load(f2)
+
+        datas = np.random.randn(40)
+        for i in datas:
+            mr.push(dict(x=i, y=i+1.))
+            pickled.push(dict(x=i, y=i+1.))
+
+        self.assertAlmostEqual(mr.value, pickled.value)
+        os.unlink(f.name)
+
 
 if __name__ == '__main__':
     unittest.main()
